# Table of Contents

- [responding-to-surveys](<./responding-to-surveys.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Responding to Surveys](<./Responding-to-Surveys.md>)
  - [Introduction](<./Responding-to-Surveys/Introduction.md>)
  - [Accessing the Survey Response Form](<./Responding-to-Surveys/Accessing-the-Survey-Response-Form.md>)
  - [Accessing Survey from the Dashboard](<./Responding-to-Surveys/Accessing-Survey-from-the-Dashboard.md>)
  - [Responding to Surveys](<./Responding-to-Surveys/Responding-to-Surveys.md>)
